@@ -462,6 +462,8 @@ sub getConfigBlob {
 
     my $zip = Archive::Zip->new();
     my $cfg = $self->cfgHash;
+    # flush all the changes in the database to the db file
+    $self->app->database->sql->db->dbh->do('PRAGMA wal_checkpoint;');
     $zip->addFile({
         filename => $cfg->{BACKEND}{cfg_db},
         zipName => '{DATABASE}',
